Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/prusa3d/PrusaSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/slic3r/Config/Snapshot.hpp')
-rw-r--r--src/slic3r/Config/Snapshot.hpp17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/slic3r/Config/Snapshot.hpp b/src/slic3r/Config/Snapshot.hpp
index 9a7391691..48add8a1a 100644
--- a/src/slic3r/Config/Snapshot.hpp
+++ b/src/slic3r/Config/Snapshot.hpp
@@ -6,7 +6,7 @@
#include <string>
#include <vector>
-#include <boost/filesystem.hpp>
+#include <boost/filesystem/path.hpp>
#include "libslic3r/Semver.hpp"
#include "Version.hpp"
@@ -18,14 +18,16 @@ class AppConfig;
namespace GUI {
namespace Config {
-class Index;
// A snapshot contains:
// Slic3r.ini
// vendor/
// print/
+// sla_print/
// filament/
+// sla_material
// printer/
+// physical_printer/
class Snapshot
{
public:
@@ -43,12 +45,12 @@ public:
void load_ini(const std::string &path);
void save_ini(const std::string &path);
// Export the print / filament / printer selections to be activated into the AppConfig.
void export_selections(AppConfig &config) const;
void export_vendor_configs(AppConfig &config) const;
// Perform a deep compare of the active print / filament / printer / vendor directories.
// Return true if the content of the current print / filament / printer / vendor directories
// matches the state stored in this snapshot.
bool equal_to_active(const AppConfig &app_config) const;
@@ -66,8 +68,11 @@ public:
// Active presets at the time of the snapshot.
std::string print;
+ std::string sla_print;
std::vector<std::string> filaments;
+ std::string sla_material;
std::string printer;
+ std::string physical_printer;
// Annotation of the vendor configuration stored in the snapshot.
// This information is displayed to the user and used to decide compatibility
@@ -98,7 +103,7 @@ public:
size_t load_db();
void update_slic3r_versions(std::vector<Index> &index_db);
// Create a snapshot directory, copy the vendor config bundles, user print/filament/printer profiles,
// create an index.
const Snapshot& take_snapshot(const AppConfig &app_config, Snapshot::Reason reason, const std::string &comment = "");
const Snapshot& restore_snapshot(const std::string &id, AppConfig &app_config);
@@ -43,12 +45,12 @@ public:
void load_ini(const std::string &path);
void save_ini(const std::string &path);
- // Export the print / filament / printer selections to be activated into the AppConfig.
+ // Export the print / sla_print / filament / sla_material / printer selections to be activated into the AppConfig.
void export_selections(AppConfig &config) const;
void export_vendor_configs(AppConfig &config) const;
@@ -43,12 +45,12 @@ public:
void export_selections(AppConfig &config) const;
void export_vendor_configs(AppConfig &config) const;
- // Perform a deep compare of the active print / filament / printer / vendor directories.
- // Return true if the content of the current print / filament / printer / vendor directories
+ // Perform a deep compare of the active print / sla_print / filament / sla_material / printer / physical_printer / vendor directories.
+ // Return true if the content of the current print / sla_print / filament / sla_material / printer / physical_printer / vendor directories
// matches the state stored in this snapshot.
bool equal_to_active(const AppConfig &app_config) const;
@@ -98,7 +103,7 @@ public:
size_t load_db();
void update_slic3r_versions(std::vector<Index> &index_db);
- // Create a snapshot directory, copy the vendor config bundles, user print/filament/printer profiles,
+ // Create a snapshot directory, copy the vendor config bundles, user print / sla_print / filament / sla_material / printer / physical_printer profiles,
// create an index.
const Snapshot& take_snapshot(const AppConfig &app_config, Snapshot::Reason reason, const std::string &comment = "");